==> stellarium_0.14.3.orig.tar.gz: stellarium-0.14.3/src/tests/testStelSphereGeometry.hpp <==
/*
 * Stellarium
 * Copyright (C) 2009 Fabien Chereau
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */

#ifndef _TESTSTELSPHERICALGEOMETRY_HPP_
#define _TESTSTELSPHERICALGEOMETRY_HPP_

#include <QObject>
#include <QTest>
#include "StelSphereGeometry.hpp"

class TestStelSphericalGeometry : public QObject
{
Q_OBJECT
private slots:
	void initTestCase();
	void testOctahedronPolygon();
	void testSphericalCap();
	void testContains();
	void testPlaneIntersect2();
	void testGreatCircleIntersection();
	void testSphericalPolygon();
	void testConsistency();
	void testLoading();
	void testEnlarge();
	void benchmarkContains();
	void benchmarkCheckValid();
	void benchmarkSphericalCap();
	void benchmarkGetIntersection();
	void testSerialize();
	void benchmarkCreatePolygon();
private:
	SphericalPolygon holySquare;
	SphericalPolygon bigSquare;
	SphericalPolygon smallSquare;
	SphericalPolygon opositeSquare;
	SphericalConvexPolygon bigSquareConvex;
	SphericalConvexPolygon smallSquareConvex;
	SphericalConvexPolygon triangle;
	SphericalPolygon northPoleSquare;
	SphericalPolygon southPoleSquare;
};

#endif // _TESTSTELSPHERICALGEOMETRY_HPP_

==> stellarium_0.18.3.orig.tar.gz: stellarium-0.18.3/src/tests/testStelSphereGeometry.hpp <==
/*
 * Stellarium
 * Copyright (C) 2009 Fabien Chereau
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */

#ifndef TESTSTELSPHERICALGEOMETRY_HPP
#define TESTSTELSPHERICALGEOMETRY_HPP

#include <QObject>
#include <QTest>
#include "StelSphereGeometry.hpp"

class TestStelSphericalGeometry : public QObject
{
Q_OBJECT
private slots:
	void initTestCase();
	void testOctahedronPolygon();
	void testSphericalCap();
	void testContains();
	void testPlaneIntersect2();
	void testGreatCircleIntersection();
	void testSphericalPolygon();
	void testConsistency();
	void testLoading();
	void testEnlarge();
	void benchmarkContains();
	void benchmarkCheckValid();
	void benchmarkSphericalCap();
	void benchmarkGetIntersection();
	void testSerialize();
	void benchmarkCreatePolygon();
private:
	SphericalPolygon holySquare;
	SphericalPolygon bigSquare;
	SphericalPolygon smallSquare;
	SphericalPolygon opositeSquare;
	SphericalConvexPolygon bigSquareConvex;
	SphericalConvexPolygon smallSquareConvex;
	SphericalConvexPolygon triangle;
	SphericalPolygon northPoleSquare;
	SphericalPolygon southPoleSquare;
};

#endif // _TESTSTELSPHERICALGEOMETRY_HPP
